// Some functions for form processing...
#ifndef RH_FORM_H
#define RH_FORM_H 1

#include <string>
#include <list>
#include "html.h"

class OptionBoxItem;

typedef list<string> stringlist;
typedef list<string>::iterator stringlist_it;
typedef list<OptionBoxItem> Options;

/** Class for creation of HTML forms
  */
class form: public HTML {
public:
        /** Method (as in <form method="something">)
	  */
	enum Method { POST, GET };
	/** Constructor - create a new HTML form
	  * @param action CGI script to be called when submit is clicked
	  * @param m Method (POST or GET)
	  */
	form(string action, enum Method m=POST);
	~form();
	
	/** Add a text input widget
	  * @param name name of widget (and output variable)
	  * @param label label
	  * @param hidden If true, the user's input won't be displayed (passwords etc.)
	  * @param size size of widget (in characters)
	  */
	void addInput(string name, string label="", bool hidden=false, int size=-1);
	
	/** Add a radio button
	  * @param group Button group
	  * @param name Button name
	  * @param label label
	  * @param checked if true, this button is checked by default.
	  */
	void addRadio(string group, string name, string label="", bool checked=false);

	/** Add a checkbox
	  * @param name Button name
	  * @param label label
	  * @param checked if true, this button is checked by default.
	  */
	void addCheckBox(string name, string label="", bool checked=false);

	/** Add Options
	  * @param o
	  * Option list
	  */
	void addOptions(Options &o, string name);

	/** Add a submit button
	  * @param text displayed text (defaults to Submit Query in most
	  * browsers)
	  */
	void addSubmit(string text="");

	/** Pass a variable to another CGI launched by us
	  * (this creates an <input type="hidden"> tag)
	  * @param variable variable name
	  * @param value value
	  */
	void addPassThrough(string variable, string value);

	/** Convert to string
	  */
	operator string();
};

/** Entry for an option selector
  */
class OptionBoxItem {
public:
	/** Create an option
	  * @param name name of the item
	  * @param label of the item
	  */
	OptionBoxItem(string name, string label) { n=name; l=label; };
	/** Get HTML code for the option item
	  * (primarily for internal use)
	  */
	operator string() { return (string)"<option value=\""+n+"\">"+l+"</option>"; };
private:
	string n;
	string l;
};
#endif
