// Some functions for socket handling...
#ifndef RH_SOCKET_H
#define RH_SOCKET_H 1

#include <string>
#include <iostream>
extern "C" {
#include <sys/socket.h>
}

/** Class for socket handling...
  */
class Socket {
	friend ostream &operator <<(ostream &o, Socket &s);
	friend void operator <<(Socket *s, string str);
public:
	enum status { NotConnected, Connected, Listening };
	/** Constructor - create a socket...
	  * @param host hostname or IP of host to connect to. Empty if you
	  *        don't want to establish a connection yet.
	  * @param port port to connect to. -1 if you don't want to establish
	  *        a connection yet.
	  * @param domain communication domain (as required by socket(2))
	  * @param type socket type (as required by socket(2))
	  * @param protocol protocol type (as required by socket(2))
	  */
	Socket(string host="", int port=-1, int domain=PF_INET, int type=SOCK_STREAM, int protocol=0);
	~Socket();
	/** read data from a socket.
	  * @return string containing all data currently available on the socket
	  */
	string read();
	/** read reply from a socket.
	  * Returns the number code virtually all TCP/IP protocols use,
	  * ignoring the clear text part
	  * For example, this would return 220 after connecting to an SMTP
	  * server (which outputs something like 220 hostname blah blah).
	  * @param request send this request before looking for a reply
	  * @return number code returned by server
	  */
	int reply(string request="");
	/** Write data to a socket...
	  * @param s Data to write to the socket
	  */
	void operator <<(string s);
private:
	int socket_fd;
	enum status st;
};

ostream &operator <<(ostream &o, Socket &s);
void operator <<(Socket *s, string str);

#endif
